## Installation

### Using uv (Recommended)

You can install the `crowdcent-challenge` python client, CLI and, scoring functions using `uv`:

```bash
uv pip install crowdcent-challenge
```

### Using pip

If you prefer `pip`:

```bash
pip install crowdcent-challenge
```